@@ -569,6 +569,47 @@ def global_install():
     installer = MCPInstaller(project_root_path=Path.cwd())
     installer.install_and_configure_mcp()
 
+@app.command()
+def update():
+    """Update starbase to the latest version from PyPI."""
+    import subprocess
+    import shutil
+    
+    console.print("\n[cyan]🔄 Updating starbase to latest version...[/cyan]")
+    
+    pipx_path = shutil.which("pipx")
+    if pipx_path:
+        try:
+            # First uninstall existing version
+            console.print("[dim]Uninstalling current version...[/dim]")
+            subprocess.run([pipx_path, "uninstall", "starbase-code"], capture_output=True, text=True)
+            
+            # Install latest from PyPI
+            console.print("[dim]Installing latest version from PyPI...[/dim]")
+            result = subprocess.run([pipx_path, "install", "starbase-code"], capture_output=True, text=True)
+            
+            if result.returncode == 0:
+                # Run MCP installer to ensure Claude Desktop integration
+                console.print("\n[cyan]🔗 Ensuring Claude Desktop integration...[/cyan]")
+                installer = MCPInstaller(project_root_path=Path.cwd())
+                installer._ensure_standard_path_access("starbase")
+                installer._update_claude_config()
+                installer._update_claude_code_config()
+                
+                console.print("\n[bold green]✅ Starbase updated successfully![/bold green]")
+                console.print("[dim]Restart your terminal or Claude Desktop to use the new version.[/dim]")
+            else:
+                console.print(f"[red]❌ Update failed: {result.stderr}[/red]")
+                console.print("[yellow]Try running: pipx install starbase-code[/yellow]")
+        except Exception as e:
+            console.print(f"[red]❌ Update error: {e}[/red]")
+            console.print("[yellow]Try running: pipx install starbase-code[/yellow]")
+    else:
+        console.print("[red]❌ pipx not found. Install pipx first:[/red]")
+        console.print("  macOS: [cyan]brew install pipx[/cyan]")
+        console.print("  Linux: [cyan]sudo apt install pipx[/cyan]")
+        console.print("  Or:    [cyan]python3 -m pip install --user pipx[/cyan]")
+
 
 
 
